#ifndef K32W0x2_DEVICE_H_
#define K32W0x2_DEVICE_H_

#include <stdint.h>

/* one block for each device/algorithm */
/*-----------------------------------------------------------------------*/
#if   defined K32W0x2

  static __inline void Watchdog_Disable(void) {
    /* M4 */
    (*((volatile uint32_t *)(0x4002A004u))) = 0xD928C520u;  /* WDOG0->CNT = WDOG_UPDATE_KEY; */
    (*((volatile uint32_t *)(0x4002A008u))) = 0xFFFFu;      /* WDOG0->TOVAL = 0xFFFF; */
    (*((volatile uint32_t *)(0x4002A000u))) = 0x2920u;      /* WDOG0->CS = (uint32_t) ((WDOG0->CS) & ~WDOG_CS_EN_MASK) | WDOG_CS_UPDATE_MASK; */

    /* M0+ */
    (*((volatile uint32_t *)(0x41026004u))) = 0xD928C520u;  /* WDOG1->CNT = WDOG_UPDATE_KEY; */
    (*((volatile uint32_t *)(0x41026008u))) = 0xFFFFu;      /* WDOG1->TOVAL = 0xFFFF; */
    (*((volatile uint32_t *)(0x41026000u))) = 0x2920u;      /* WDOG1->CS = (uint32_t) ((WDOG1->CS) & ~WDOG_CS_EN_MASK) | WDOG_CS_UPDATE_MASK; */
  }

  static __inline void RunMode_Set(void) {
    /* Disable cache to ensure that all flash operations will take effect instantly (this is device dependent) */

    (*((volatile uint32_t *)(0x4002B004U)))  = 0xE0000000U;   /* enable clock for MSCM */
    (*((volatile uint32_t *)(0x40001400U))) |= ((1U << 4) |   /* Data Prefetch disable */
                                                (1U << 5)  ); /* Flash Speculate disable */
    (*((volatile uint32_t *)(0x40001404U))) |= ((1U << 4) |   /* Data Prefetch disable */
                                                (1U << 5)  ); /* Flash Speculate disable */


/* Note:
   Cache disable is different for M4 and M0+ and done via MCM registers.
   Only the MCM of the bboting core is clocked by default.   
   A HardFault is thrown if the MCM of the non booting core is accessed.
   But I think it is enough to disable the cache of the booting core.
 */
    if ((*((volatile uint32_t *)(0x40001004U))) == 0U) {         /* check MSCM.CPxNUM */
     /* Disable M4 cache in MCM */
     (*((volatile uint32_t *)(0xE0080034U))) |= ((1U <<  1) |    /* disable cache write buffer (DCCWB) */
                                                 (1U <<  3)  );  /* disable code bus cache (DCBC) */
    }
    else {
      /* Disable M0+ cache in MCM */
      (*((volatile uint32_t *)(0xF0003034U))) |= ((1U <<  1) |    /* disable cache write buffer (DCCWB) */
                                                  (1U <<  3) |    /* disable code cache (DCC) */
                                                  (1U <<  9) |    /* disable cache write buffer (DSCWB) */
                                                  (1U << 11)  );  /* System Cache disable (DSC) */
    }

  }

  /* destination to program security key back to flash location */
  /* not applicable */

#else
  #error "flash_device not configured."
#endif

#endif /* #if K32W0x2_DEVICE_H_ */
